package com.chuanglan.shanyan_sdk_test_demo.view;

import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;

import com.chuanglan.shanyan_sdk.OneKeyLoginManager;
import com.chuanglan.shanyan_sdk.listener.ActionListener;
import com.chuanglan.shanyan_sdk.listener.OneKeyLoginListener;
import com.chuanglan.shanyan_sdk.listener.OpenLoginAuthListener;
import com.chuanglan.shanyan_sdk_test_demo.R;
import com.chuanglan.shanyan_sdk_test_demo.utils.AbScreenUtils;
import com.chuanglan.shanyan_sdk_test_demo.utils.ConfigUtils;


public class HomeActivity extends BaseActivity implements View.OnClickListener {
    private LinearLayout home_land_model;
    private LinearLayout home_dialog_model;
    private LinearLayout home_debug_model;
    private LinearLayout home_port_model;
    private long startTime;
    private RelativeLayout loading_view;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE) {
            setContentView(R.layout.shanyan_demo_activity_home_land);
        } else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
            setContentView(R.layout.shanyan_demo_activity_home);
        }
        initViews();
        setListener();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE) {
            setContentView(R.layout.shanyan_demo_activity_home_land);
        } else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
            setContentView(R.layout.shanyan_demo_activity_home);
        }
        initViews();
        setListener();
    }

    private void setListener() {
        //闪验SDK 协议、协议复选框  点击事件监听（开发者无此需求可不加）
        OneKeyLoginManager.getInstance().setActionListener(new ActionListener() {
            @Override
            public void ActionListner(int type, int code, String message) {
                //type、code、message具体对应信息请参考接入文档
                //AbScreenUtils.showToast(getApplicationContext(), "_type=" + type + "_code=" + code + "_message=" + message);
            }
        });
        home_land_model.setOnClickListener(this);
        home_dialog_model.setOnClickListener(this);
        home_debug_model.setOnClickListener(this);
        home_port_model.setOnClickListener(this);
    }


    private void initViews() {
        home_land_model = findViewById(R.id.shanyan_dmeo_home_fullscreen_model);
        home_dialog_model = findViewById(R.id.shanyan_dmeo_home_dialog_model);
        home_debug_model = findViewById(R.id.shanyan_dmeo_home_debug_model);
        home_port_model = findViewById(R.id.shanyan_dmeo_home_auth_model);
        loading_view = findViewById(R.id.shanyan_dmeo_my_dialog_layout);
    }


    private void openLoginActivity() {
        //拉授权页方法
        OneKeyLoginManager.getInstance().openLoginAuth(false, new OpenLoginAuthListener() {
            @Override
            public void getOpenLoginAuthStatus(int code, String result) {
                if (null != loading_view) {
                    loading_view.setVisibility(View.GONE);
                }
                if (1000 == code) {
                    //拉起授权页成功
                    Log.e("VVV", "拉起授权页成功： _code==" + code + "   _result==" + result);
                } else {
                    //拉起授权页失败
                    Log.e("VVV", "拉起授权页失败： _code==" + code + "   _result==" + result);
                    AbScreenUtils.showToast(getApplicationContext(), result);
                }
            }
        }, new OneKeyLoginListener() {
            @Override
            public void getOneKeyLoginStatus(int code, String result) {
                if (null != loading_view) {
                    loading_view.setVisibility(View.GONE);
                }
                if (1011 == code) {
                    Log.e("VVV", "用户点击授权页返回： _code==" + code + "   _result==" + result);
                    return;
                } else if (1000 == code) {
                    Log.e("VVV", "用户点击登录获取token成功： _code==" + code + "   _result==" + result);
                    //OneKeyLoginManager.getInstance().setLoadingVisibility(false);
                    //AbScreenUtils.showToast(getApplicationContext(), "用户点击登录获取token成功");
                } else {
                    Log.e("VVV", "用户点击登录获取token失败： _code==" + code + "   _result==" + result);
                }
                startTime = System.currentTimeMillis();
                startResultActivity(code, result);
            }
        });
    }

    private void startResultActivity(int code, String result) {
        Intent intent = new Intent(HomeActivity.this, ResultActivity.class);
        intent.putExtra("type", "0");
        intent.putExtra("startTime", startTime);
        intent.putExtra("loginResult", result);
        intent.putExtra("loginCode", code);
        startActivity(intent);
        OneKeyLoginManager.getInstance().finishAuthActivity();
    }


    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            //全屏模式
            case R.id.shanyan_dmeo_home_fullscreen_model:
                if (null != home_land_model) {
                    home_land_model.setClickable(false);
                }
                loading_view.setVisibility(View.VISIBLE);
                Intent dialogIntent = new Intent(HomeActivity.this, LoginActivity.class);
                startActivity(dialogIntent);
                break;
            //弹框模式
            case R.id.shanyan_dmeo_home_dialog_model:
                loading_view.setVisibility(View.VISIBLE);
                //授权页配置
                OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getDialogUiConfig(getApplicationContext()), ConfigUtils.getLandscapeUiConfig(getApplicationContext()));
                //拉授权页
                openLoginActivity();
                break;
            //本机号验证
            case R.id.shanyan_dmeo_home_auth_model:
                //跳转到本机号认证页面
                Intent authIntent = new Intent(HomeActivity.this, AuthenticationActivity.class);
                startActivity(authIntent);
                break;
            //调试模式
            case R.id.shanyan_dmeo_home_debug_model:
                Intent debugIntent = new Intent(HomeActivity.this, DebugModeActivity.class);
                startActivity(debugIntent);
                break;

        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (loading_view != null) {
            loading_view.setVisibility(View.GONE);
        }
        if (null != home_land_model) {
            home_land_model.setClickable(true);
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (loading_view != null) {
            loading_view.setVisibility(View.GONE);
        }
        OneKeyLoginManager.getInstance().removeAllListener();
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (loading_view != null) {
            loading_view.setVisibility(View.GONE);
        }
    }

}
